<?php
class obox_newsletter_widget extends WP_Widget {
	/** constructor */

	function __construct() {
		$widget_ops = array('classname' => 'widget_text', 'description' => __('"Custom text widget with the Obox widget styling."'));
		$control_ops = array('width' => 400, 'height' => 350);
		parent::__construct('obox_newsletter_widget', __("(Obox) Newsletter Widget", "ocmx"), $widget_ops, $control_ops);
	}

	/** @see WP_Widget::widget */
	function widget( $args, $instance ) {

		// Turn $args array into variables.
		extract( $args );

		// Turn $instance array into variables
		$instance_defaults = array ( 'title_align' => 'centeralign' );
		$instance_args = wp_parse_args( $instance, $instance_defaults );
		extract( $instance_args, EXTR_SKIP );

		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
		$byline = apply_filters( 'widget_text', empty( $instance['byline'] ) ? '' : $instance['byline'], $instance );

		// Widget Background CSS
		if( isset( $background_image ) ) $css = obox_widget_generate_css( array( "widget_id" => $widget_id , "input" => $background_image , "type" => "background" ) );

		// Widget Title & Excerpt CSS
		if( isset( $text_color ) ) $title_excerpt_css =  obox_widget_generate_css( array( "widget_id" => $widget_id , "input" => $text_color , "type" => "color" , "selectors" => array ( ".title h2" , ".title h3", "form" ) ) ); ?>

		<li class="newsletter" id="<?php echo $widget_id; ?>">
			<div class="newsletter-content">
                <div class="title">
                    <?php if(isset($title) && $title != "") { ?><h2><?php echo $title; ?></h2><?php } ?>
                    <?php if(isset($byline) && $byline !='') { ?><h3><?php echo $byline; ?></h3><?php } ?>
                </div><!-- /Title -->
				<div class="newsletter-form">
					<?php if(isset($embed) && $embed !='') echo $embed; ?>
				</div>
			</div>
		</li><!-- /newsletter -->

<?php
	}

	/** @see WP_Widget::update */

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['byline'] =  $new_instance['byline'];
		$instance['embed'] =  $new_instance['embed'];

		$instance['filter'] = isset($new_instance['filter']);
		$instance['background_image'] = $new_instance['background_image'];
		$instance['text_color'] = $new_instance['text_color'];
		$instance['title_align'] = $new_instance['title_align'];

		return $instance;
	}

	/** @see WP_Widget::form */
	function form($instance) {

		// Turn $instance array into variables
		$instance_defaults = array ( 'title_align' => 'centeralign' );
		$instance_args = wp_parse_args( $instance, $instance_defaults );
		extract( $instance_args, EXTR_SKIP ); ?>

	<p>
		<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e("Title", "ocmx"); ?><input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php if( isset($title) ) echo $title; ?>" /></label>
	</p>

	<p>
		<label for="<?php echo $this->get_field_id('byline'); ?>">
			<?php _e("Byline", "ocmx"); ?>
			<textarea class="widefat" rows="16" cols="20" id="<?php echo $this->get_field_id('byline'); ?>" name="<?php echo $this->get_field_name('byline'); ?>"><?php if( isset($byline) ) echo $byline; ?></textarea>
		</label>
	</p>

	<p>
		<label for="<?php echo $this->get_field_id('embed'); ?>">
			<?php _e("Newsletter Embed Code", "ocmx"); ?>
			<textarea class="widefat" rows="16" cols="20" id="<?php echo $this->get_field_id('embed'); ?>" name="<?php echo $this->get_field_name('embed'); ?>"><?php if( isset($embed) ) echo $embed; ?></textarea>


		</label>
	</p>

	<?php $alignment = array('leftalign' => 'Left Align', 'centeralign' => 'Centered', 'rightalign' => 'Right Align'); ?>
	<p>
		<label for="<?php echo $this->get_field_id('title_align'); ?>"><?php _e("Title & Description Alignment", "ocmx"); ?></label>
		<select size="1" class="widefat" id="<?php echo $this->get_field_id('title_align'); ?>" name="<?php echo $this->get_field_name('title_align'); ?>">
			<?php foreach($alignment as $value => $label) : ?>
				<option <?php if(isset($title_align) && $title_align == $value) : ?>selected="selected"<?php endif; ?> value="<?php echo $value; ?>"><?php echo $label; ?></option>
			<?php endforeach; ?>
		</select>
	</p>

<?php
	} // form

}// class

//This sample widget can then be registered in the widgets_init hook:

// register FooWidget widget
add_action('widgets_init', create_function('', 'return register_widget("obox_newsletter_widget");'));
add_filter('widget_text', 'do_shortcode');